#ifndef _DIMEDIT_H
#define _DIMEDIT_H

/**
 * Class  : DimTextCtrl
 * Author : S.A.W. - Franky Braem
 *
 * Description :
 *
 * This class subclasses a wxTextCtrl, which displays a "dimmed" string when the control is
 * empty and does not have the keyboard focus. When the control gets the focus, the dimmed text
 * disappears.
 *
 * The value of wxTextCtrl is not modified by the control in any way. This way, the GetValue()
 * and SetValue() functions do not need to be modified. All of the work is done in the OnPaint
 * message handler.
 *
 * Remark :
 *
 * DimTextCtrl is based on DimEdit, a WTL Control created by Paul A. Howes.
 */
class DimTextCtrl : public wxTextCtrl
{
public:
  /**
   * Constructor
   */
  DimTextCtrl(wxWindow *parent,
              wxWindowID id,
              const wxString& dim,
              const wxColour& dimColour = wxColour(128, 128, 128),
              const wxString& value = "",
              const wxPoint& pos = wxDefaultPosition,
              const wxSize &size = wxDefaultSize,
              long style = 0,
              const wxValidator& validator = wxDefaultValidator,
              const wxString& name = "dimedit");

   /**
    * SetDimText - Set the text to display when the control is empty.
    */
   void SetDimText(const wxString& dim)
   {
     m_dimText = dim;
   }

   /**
    * SetDimColour - Set the colour of the dimmed text.
    */
   void SetDimColour(const wxColour& dimColour)
   {
     m_dimColour = dimColour;
   }

   /**
    * SetDimColour - Set the colour of the dimmed text.
    */
   void SetDimColour(const unsigned char red,
                     const unsigned char green,
                     const unsigned char blue)
   {
     m_dimColour = wxColour(red, green, blue);
   }

   /**
    * GetDimColour - Returns the colour used for the dimmed text
    */
   wxColour GetDimColour(void) const
   {
     return m_dimColour;
   }
   /**
    * GetDimText - Returns the text used to display when the control is empty.
    */
   wxString GetDimText(void) const
   {
     return m_dimText;
   }

   /**
    * IsDimmed - Returns true when the dimmed text is shown.
    */
   bool IsDimmed() const
   {
     return m_isDimmed;
   }

   /**
    * SetDimmed - Set the dimmed status.
    */
   void SetDimmed(bool dimmed)
   {
     m_isDimmed = dimmed;
     Refresh();
   }

protected:

  /**
   * OnPaint - Handles the paint event
   */
  void OnPaint(wxPaintEvent &event);

  /**
   * OnSetFocus - Handles the setfocus event
   */
  void OnSetFocus(wxFocusEvent &event);

  /**
   * OnKillFocus - Handles the killfocus event
   */
  void OnKillFocus(wxFocusEvent &event);

  DECLARE_EVENT_TABLE()

private:

  wxColour m_dimColour;
  wxString m_dimText;
  bool m_isDimmed;

};

#endif //_DIMEDIT_H

